@@ -1,5 +1,6 @@
+import array
 import unittest
-from toytable.columns import Column
+from toytable.columns import Column, ArrayColumn
 
 
 class TestColumn(unittest.TestCase):
@@ -19,5 +20,6 @@ class TestColumn(unittest.TestCase):
         c = Column('foo', range(3), type=int)
         self.assertEqual(list(c), [0, 1, 2])
 
+
 if __name__ == '__main__':
     unittest.main()
