@@ -42,4 +42,4 @@ class TestProject(unittest.TestCase):
 
 
 if __name__ == '__main__':
-    main()
+    unittest.main()
